@@ -3,7 +3,7 @@ Top-level module containing convenience functions.
 """
 
 from .common import Metadata, ProtocolError, SSLArgument
-from .retry import RetryConfiguration, metadata, upload
+from .retry import RetryConfiguration, metadata, upload, upload_multiple
 
 __all__ = (
     "Metadata",
@@ -12,4 +12,5 @@ __all__ = (
     "SSLArgument",
     "metadata",
     "upload",
+    "upload_multiple",
 )
