@@ -75,6 +75,7 @@ async def offset(
     :param ssl: SSL validation mode, passed on to aiohttp.
     :param headers: Optional headers used in the request.
     :return: The number of bytes that are already on the server.
+    :raises ProtocolError: When the server does not comply to the tus protocol.
     """
 
     tus_headers = dict(headers or {})
@@ -85,7 +86,7 @@ async def offset(
         response.raise_for_status()
 
         if "Upload-Offset" not in response.headers:
-            raise RuntimeError(
+            raise common.ProtocolError(
                 f"HEAD request succeeded for {location}, "
                 'but no "Upload-Offset" header in response.'
             )
@@ -126,6 +127,9 @@ async def metadata(
     :param ssl: SSL validation mode, passed on to aiohttp.
     :param headers: Optional headers used in the request.
     :return: The metadata of the upload.
+    :raises ProtocolError: When the server does not comply to the tus protocol.
+
+    .. # noqa: DAR401 asyncio.CancelledError
     """
 
     tus_headers = dict(headers or {})
@@ -162,6 +166,8 @@ async def upload_buffer(
     :param ssl: SSL validation mode, passed on to aiohttp.
     :param chunksize: The size of individual chunks to upload at a time.
     :param headers: Optional headers used in the request.
+    :raises ProtocolError: When the server does not comply to the tus protocol.
+    :raises RuntimeError: When reading of the file fails.
     """
 
     loop = asyncio.get_event_loop()
@@ -239,6 +245,7 @@ async def configuration(
     :param ssl: SSL validation mode, passed on to aiohttp.
     :param headers: Optional headers used in the request.
     :return: An object describing the server's configuration.
+    :raises ProtocolError: When the server does not comply to the tus protocol.
     """
 
     logger.debug("Querying server configuration...")
