@@ -18,7 +18,7 @@ from typing import (
 )
 
 import aiohttp
-import tenacity  # type: ignore
+import tenacity
 import yarl
 
 from . import common, core, creation
@@ -106,13 +106,17 @@ def _make_log_before_sleep_function(
     return log
 
 
-def _make_retrying(s: str, config: RetryConfiguration) -> tenacity.AsyncRetrying:
+def _make_retrying(
+    s: str, config: RetryConfiguration
+) -> tenacity.AsyncRetrying:  # type: ignore
     """Create a tenacity retry object."""
 
-    return tenacity.AsyncRetrying(
-        retry=tenacity.retry_if_exception_type(aiohttp.ClientError),
-        stop=tenacity.stop_after_attempt(config.retry_attempts),
-        wait=tenacity.wait_exponential(max=config.max_retry_period_seconds),
+    return tenacity.AsyncRetrying(  # type: ignore
+        retry=tenacity.retry_if_exception_type(aiohttp.ClientError),  # type: ignore
+        stop=tenacity.stop_after_attempt(config.retry_attempts),  # type: ignore
+        wait=tenacity.wait_exponential(  # type: ignore
+            max=config.max_retry_period_seconds
+        ),
         before=_make_log_before_function(s),
         before_sleep=_make_log_before_sleep_function(s),
     )
@@ -142,6 +146,8 @@ async def upload(
     :param headers: Optional headers used in the request.
     :param chunksize: The size of individual chunks to upload at a time.
     :return: The location where the file was uploaded to (if the upload succeeded).
+
+    .. # noqa: DAR401 asyncio.CancelledError
     """
 
     url = yarl.URL(endpoint)
@@ -160,28 +166,30 @@ async def upload(
             ctx = asyncnullcontext(client_session)
 
         async with ctx as session:
-            location: yarl.URL
-            location = await retrying_create.call(
-                creation.create,
-                session,
-                url,
-                file,
-                metadata,
-                ssl=config.ssl,
-                headers=headers,
-            )
+            async for attempt in retrying_create:
+                with attempt:
+                    location = await creation.create(
+                        session,
+                        url,
+                        file,
+                        metadata,
+                        ssl=config.ssl,
+                        headers=headers,
+                    )
+
             if not location.is_absolute():
                 location = url / location.path
 
-            await retrying_upload_file.call(
-                core.upload_buffer,
-                session,
-                location,
-                file,
-                ssl=config.ssl,
-                chunksize=chunksize,
-                headers=headers,
-            )
+            async for attempt in retrying_upload_file:
+                with attempt:
+                    await core.upload_buffer(
+                        session,
+                        location,
+                        file,
+                        ssl=config.ssl,
+                        chunksize=chunksize,
+                        headers=headers,
+                    )
 
             return location
     except asyncio.CancelledError:  # pragma: no cover
@@ -211,6 +219,8 @@ async def metadata(
     :param config: Settings to customize the retry behaviour.
     :param headers: Optional headers used in the request.
     :return: The metadata associated with the upload.
+
+    .. # noqa: DAR401 asyncio.CancelledError
     """
 
     if isinstance(endpoint, str):
@@ -229,11 +239,11 @@ async def metadata(
 
         async with ctx as session:
             md: common.Metadata
-            md = await retrying_metadata.call(
-                core.metadata, session, url, ssl=config.ssl, headers=headers
-            )
-
-            return md
+            async for attempt in retrying_metadata:
+                with attempt:
+                    return await core.metadata(
+                        session, url, ssl=config.ssl, headers=headers
+                    )
     except asyncio.CancelledError:  # pragma: no cover
         raise
     except tenacity.RetryError as e:
@@ -289,8 +299,11 @@ async def upload_multiple(
     :param config: Settings to customize the retry behaviour.
     :param headers: Optional headers used in the request.
     :param chunksize: The size of individual chunks to upload at a time.
-    :param parallel_upload: The number of parallel uploads to do concurrently.
+    :param parallel_uploads: The number of parallel uploads to do concurrently.
     :return: The location of the final (concatenated) file on the server.
+    :raises RuntimeError: If the server does not support the "concatenation" extension.
+
+    .. # noqa: DAR401 asyncio.CancelledError
     """
 
     url = yarl.URL(endpoint)
@@ -312,9 +325,11 @@ async def upload_multiple(
             #
             # Check if the server supports the "concatenation" extension.
             #
-            server_config = await retrying_config.call(
-                core.configuration, session, url, ssl=config.ssl, headers=headers
-            )
+            async for attempt in retrying_config:
+                with attempt:
+                    server_config = await core.configuration(
+                        session, url, ssl=config.ssl, headers=headers
+                    )
 
             if "concatenation" not in server_config.protocol_extensions:
                 raise RuntimeError(
@@ -356,18 +371,16 @@ async def upload_multiple(
             final_headers = dict(headers or {})
             final_headers.update({"Upload-Concat": concat_header})
 
-            location: yarl.URL
-            location = await retrying_create.call(
-                creation.create,
-                session,
-                url,
-                None,
-                metadata,
-                ssl=config.ssl,
-                headers=final_headers,
-            )
-
-            return location
+            async for attempt in retrying_create:
+                with attempt:
+                    return await creation.create(
+                        session,
+                        url,
+                        None,
+                        metadata,
+                        ssl=config.ssl,
+                        headers=final_headers,
+                    )
     except asyncio.CancelledError:  # pragma: no cover
         raise
     except tenacity.RetryError as e:
